@@ -8,12 +8,12 @@
 #include <ostream>
 #include <variant>
 
+#include "glaze/core/chrono.hpp"
+#include "glaze/util/parse.hpp"
+
 #if !defined(GLZ_DISABLE_SIMD) && (defined(__x86_64__) || defined(_M_X64))
 #if defined(_MSC_VER)
 #include <intrin.h>
-#pragma warning(push)
-#pragma warning( \
-   disable : 4702) // disable "unreachable code" warnings, which are often invalid due to constexpr branching
 #else
 #include <immintrin.h>
 #endif
@@ -23,6 +23,12 @@
 #endif
 #endif
 
+#if defined(_MSC_VER) && !defined(__clang__)
+// disable "unreachable code" warnings, which are often invalid due to constexpr branching
+#pragma warning(push)
+#pragma warning(disable : 4702)
+#endif
+
 #include "glaze/core/opts.hpp"
 #include "glaze/core/reflect.hpp"
 #include "glaze/core/to.hpp"
@@ -205,6 +211,248 @@ namespace glz
       }
    };
 
+   // Runtime partial write - writes only the keys specified at runtime
+   // Outputs keys in the order they appear in the input container
+   template <class T>
+      requires(glaze_object_t<T> || reflectable<T>)
+   struct to_runtime_partial
+   {
+      template <auto Opts, class Keys, class Value, is_context Ctx, class B, class IX>
+      static void op(const Keys& keys, Value&& value, Ctx&& ctx, B&& b, IX&& ix)
+      {
+         if constexpr (!check_opening_handled(Opts)) {
+            dump<'{'>(b, ix);
+            if constexpr (Opts.prettify) {
+               ctx.indentation_level += Opts.indentation_width;
+               dump<'\n'>(b, ix);
+               dumpn<Opts.indentation_char>(ctx.indentation_level, b, ix);
+            }
+         }
+
+         using V = std::remove_cvref_t<Value>;
+         static constexpr auto N = reflect<V>::size;
+
+         if constexpr (N == 0) {
+            // Empty struct - any key is unknown
+            for (const auto& key_ref : keys) {
+               (void)key_ref;
+               ctx.error = error_code::unknown_key;
+               return;
+            }
+         }
+         else {
+            static constexpr auto& HashInfo = hash_info<V>;
+
+            decltype(auto) t = [&]() -> decltype(auto) {
+               if constexpr (reflectable<V>) {
+                  return to_tie(value);
+               }
+               else {
+                  return nullptr;
+               }
+            }();
+
+            bool first = true;
+
+            for (const auto& key_ref : keys) {
+               if (bool(ctx.error)) [[unlikely]] {
+                  return;
+               }
+
+               const sv key{key_ref};
+
+               // Use hash-based lookup to find the member index
+               const auto index = decode_hash_with_size<JSON, V, HashInfo, HashInfo.type>::op(
+                  key.data(), key.data() + key.size(), key.size());
+
+               if (index >= N) {
+                  ctx.error = error_code::unknown_key;
+                  return;
+               }
+
+               // Verify the key matches (hash collision check)
+               const sv actual_key = reflect<V>::keys[index];
+               if (key != actual_key) {
+                  ctx.error = error_code::unknown_key;
+                  return;
+               }
+
+               // Write separator if not first
+               if (first) {
+                  first = false;
+               }
+               else {
+                  write_object_entry_separator<Opts>(ctx, b, ix);
+               }
+
+               // Write the quoted key at runtime
+               if constexpr (vector_like<B>) {
+                  const auto k = ix + key.size() + 4 + (Opts.prettify ? 1 : 0);
+                  if (k > b.size()) [[unlikely]] {
+                     b.resize(2 * k);
+                  }
+               }
+               dump<'"'>(b, ix);
+               dump(key, b, ix);
+               if constexpr (Opts.prettify) {
+                  dump<"\": ">(b, ix);
+               }
+               else {
+                  dump<"\":">(b, ix);
+               }
+
+               // Use visit to dispatch to correct member and serialize value
+               visit<N>(
+                  [&]<size_t I>() {
+                     using val_t = field_t<V, I>;
+                     if constexpr (reflectable<V>) {
+                        to<JSON, val_t>::template op<Opts>(get_member(value, get<I>(t)), ctx, b, ix);
+                     }
+                     else {
+                        to<JSON, val_t>::template op<Opts>(get_member(value, get<I>(reflect<V>::values)), ctx, b, ix);
+                     }
+                  },
+                  index);
+            }
+         }
+
+         if constexpr (Opts.prettify) {
+            ctx.indentation_level -= Opts.indentation_width;
+            dump<'\n'>(b, ix);
+            dumpn<Opts.indentation_char>(ctx.indentation_level, b, ix);
+         }
+
+         if (not bool(ctx.error)) [[likely]] {
+            dump<'}'>(b, ix);
+         }
+      }
+   };
+
+   // Runtime exclude write - writes all keys EXCEPT those specified at runtime
+   // Outputs keys in struct definition order, skipping excluded keys
+   template <class T>
+      requires(glaze_object_t<T> || reflectable<T>)
+   struct to_runtime_exclude
+   {
+      template <auto Opts, class Keys, class Value, is_context Ctx, class B, class IX>
+      static void op(const Keys& exclude_keys, Value&& value, Ctx&& ctx, B&& b, IX&& ix)
+      {
+         if constexpr (!check_opening_handled(Opts)) {
+            dump<'{'>(b, ix);
+            if constexpr (Opts.prettify) {
+               ctx.indentation_level += Opts.indentation_width;
+               dump<'\n'>(b, ix);
+               dumpn<Opts.indentation_char>(ctx.indentation_level, b, ix);
+            }
+         }
+
+         using V = std::remove_cvref_t<Value>;
+         static constexpr auto N = reflect<V>::size;
+
+         if constexpr (N == 0) {
+            // Empty struct - any exclude key is unknown
+            for (const auto& key_ref : exclude_keys) {
+               (void)key_ref;
+               ctx.error = error_code::unknown_key;
+               return;
+            }
+         }
+         else {
+            static constexpr auto& HashInfo = hash_info<V>;
+
+            // First, validate all exclude keys exist and build a bitset of excluded indices
+            std::array<bool, N> excluded{};
+            for (const auto& key_ref : exclude_keys) {
+               const sv key{key_ref};
+
+               // Use hash-based lookup to find the member index
+               const auto index = decode_hash_with_size<JSON, V, HashInfo, HashInfo.type>::op(
+                  key.data(), key.data() + key.size(), key.size());
+
+               if (index >= N) {
+                  ctx.error = error_code::unknown_key;
+                  return;
+               }
+
+               // Verify the key matches (hash collision check)
+               const sv actual_key = reflect<V>::keys[index];
+               if (key != actual_key) {
+                  ctx.error = error_code::unknown_key;
+                  return;
+               }
+
+               excluded[index] = true;
+            }
+
+            decltype(auto) t = [&]() -> decltype(auto) {
+               if constexpr (reflectable<V>) {
+                  return to_tie(value);
+               }
+               else {
+                  return nullptr;
+               }
+            }();
+
+            bool first = true;
+
+            // Iterate over all keys in struct order, skipping excluded ones
+            for_each<N>([&]<size_t I>() {
+               if (bool(ctx.error)) [[unlikely]] {
+                  return;
+               }
+
+               if (excluded[I]) {
+                  return; // Skip this key
+               }
+
+               // Write separator if not first
+               if (first) {
+                  first = false;
+               }
+               else {
+                  write_object_entry_separator<Opts>(ctx, b, ix);
+               }
+
+               // Write the quoted key
+               static constexpr sv key = reflect<V>::keys[I];
+               if constexpr (vector_like<B>) {
+                  const auto k = ix + key.size() + 4 + (Opts.prettify ? 1 : 0);
+                  if (k > b.size()) [[unlikely]] {
+                     b.resize(2 * k);
+                  }
+               }
+               dump<'"'>(b, ix);
+               dump<key>(b, ix);
+               if constexpr (Opts.prettify) {
+                  dump<"\": ">(b, ix);
+               }
+               else {
+                  dump<"\":">(b, ix);
+               }
+
+               // Serialize the value
+               using val_t = field_t<V, I>;
+               if constexpr (reflectable<V>) {
+                  to<JSON, val_t>::template op<Opts>(get_member(value, get<I>(t)), ctx, b, ix);
+               }
+               else {
+                  to<JSON, val_t>::template op<Opts>(get_member(value, get<I>(reflect<V>::values)), ctx, b, ix);
+               }
+            });
+         }
+
+         if constexpr (Opts.prettify) {
+            ctx.indentation_level -= Opts.indentation_width;
+            dump<'\n'>(b, ix);
+            dumpn<Opts.indentation_char>(ctx.indentation_level, b, ix);
+         }
+
+         if (not bool(ctx.error)) [[likely]] {
+            dump<'}'>(b, ix);
+         }
+      }
+   };
+
    template <class T>
       requires(glaze_value_t<T> && !custom_write<T>)
    struct to<JSON, T>
@@ -426,7 +674,7 @@ namespace glz
             }
          }
 
-         if constexpr (Opts.bools_as_numbers) {
+         if constexpr (check_bools_as_numbers(Opts)) {
             if (value) {
                std::memcpy(&b[ix], "1", 1);
             }
@@ -536,6 +784,9 @@ namespace glz
                   if constexpr (!char_array_t<T> && std::is_pointer_v<std::decay_t<T>>) {
                      return value ? value : "";
                   }
+                  else if constexpr (u8str_t<T>) {
+                     return sv{reinterpret_cast<const char*>(value.data()), value.size()};
+                  }
                   else {
                      return sv{value};
                   }
@@ -552,15 +803,19 @@ namespace glz
                }
                // now we don't have to check writing
 
-               std::memcpy(&b[ix], "\"", 1);
-               ++ix;
+               if constexpr (not Opts.raw) {
+                  std::memcpy(&b[ix], "\"", 1);
+                  ++ix;
+               }
                if (str.size()) [[likely]] {
                   const auto n = str.size();
                   std::memcpy(&b[ix], str.data(), n);
                   ix += n;
                }
-               std::memcpy(&b[ix], "\"", 1);
-               ++ix;
+               if constexpr (not Opts.raw) {
+                  std::memcpy(&b[ix], "\"", 1);
+                  ++ix;
+               }
             }
             else {
                const sv str = [&]() -> const sv {
@@ -568,7 +823,10 @@ namespace glz
                      return value ? value : "";
                   }
                   else if constexpr (array_char_t<T>) {
-                     return *value.data() ? sv{value.data()} : "";
+                     return sv{value.data(), value.size()};
+                  }
+                  else if constexpr (u8str_t<T>) {
+                     return sv{reinterpret_cast<const char*>(value.data()), value.size()};
                   }
                   else {
                      return sv{value};
@@ -686,6 +944,9 @@ namespace glz
                         std::memcpy(data, c, 8);
                         uint64_t swar;
                         std::memcpy(&swar, c, 8);
+                        if constexpr (std::endian::native == std::endian::big) {
+                           swar = std::byteswap(swar);
+                        }
 
                         constexpr uint64_t lo7_mask = repeat_byte8(0b01111111);
                         const uint64_t lo7 = swar & lo7_mask;
@@ -772,13 +1033,8 @@ namespace glz
       template <auto Opts, class... Args>
       GLZ_ALWAYS_INLINE static void op(auto&& value, is_context auto&& ctx, Args&&... args)
       {
-         // TODO: Use new hashing approach for better performance
-         // TODO: Check if sequenced and use the value as the index if so
-         using key_t = std::underlying_type_t<T>;
-         static constexpr auto frozen_map = make_enum_to_string_map<T>();
-         const auto& member_it = frozen_map.find(static_cast<key_t>(value));
-         if (member_it != frozen_map.end()) {
-            const sv str = {member_it->second.data(), member_it->second.size()};
+         const sv str = get_enum_name(value);
+         if (!str.empty()) {
             // TODO: Assumes people dont use strings with chars that need to be escaped for their enum names
             // TODO: Could create a pre quoted map for better performance
             if constexpr (not Opts.raw) {
@@ -790,7 +1046,7 @@ namespace glz
             }
          }
          else [[unlikely]] {
-            // What do we want to happen if the value doesn't have a mapped string
+            // Value doesn't have a mapped string, serialize as underlying number
             serialize<JSON>::op<Opts>(static_cast<std::underlying_type_t<T>>(value), ctx, std::forward<Args>(args)...);
          }
       }
@@ -912,7 +1168,7 @@ namespace glz
    template <auto Opts, class Key, class Value, is_context Ctx, class B>
    GLZ_ALWAYS_INLINE void write_pair_content(const Key& key, Value&& value, Ctx& ctx, B&& b, auto&& ix)
    {
-      if constexpr (str_t<Key> || char_t<Key> || glaze_enum_t<Key> || Opts.quoted_num) {
+      if constexpr (str_t<Key> || char_t<Key> || glaze_enum_t<Key> || mimics_str_t<Key> || Opts.quoted_num) {
          to<JSON, core_t<Key>>::template op<Opts>(key, ctx, b, ix);
       }
       else if constexpr (num_t<Key>) {
@@ -1334,8 +1590,14 @@ namespace glz
                b.resize(2 * k);
             }
          }
-         static constexpr uint32_t null_v = 1819047278;
-         std::memcpy(&b[ix], &null_v, 4);
+         if constexpr (std::endian::native == std::endian::big) {
+            static constexpr char null_v[] = "null";
+            std::memcpy(&b[ix], null_v, 4);
+         }
+         else {
+            static constexpr uint32_t null_v = 1819047278;
+            std::memcpy(&b[ix], &null_v, 4);
+         }
          ix += 4;
       }
    };
@@ -1351,8 +1613,16 @@ namespace glz
                using V = std::decay_t<decltype(val)>;
 
                if constexpr (check_write_type_info(Opts) && not tag_v<T>.empty() &&
-                             (glaze_object_t<V> || (reflectable<V> && !has_member_with_name<V>(tag_v<T>)))) {
-                  constexpr auto N = reflect<V>::size;
+                             (glaze_object_t<V> || (reflectable<V> && !has_member_with_name<V>(tag_v<T>)) ||
+                              is_memory_object<V>)) {
+                  constexpr auto N = []() {
+                     if constexpr (is_memory_object<V>) {
+                        return reflect<memory_type<V>>::size;
+                     }
+                     else {
+                        return reflect<V>::size;
+                     }
+                  }();
 
                   // must first write out type
                   if constexpr (Opts.prettify) {
@@ -1367,24 +1637,21 @@ namespace glz
                      if constexpr (std::integral<id_type>) {
                         dump<"\": ">(b, ix);
                         serialize<JSON>::op<Opts>(ids_v<T>[value.index()], ctx, b, ix);
-                        if constexpr (N == 0) {
-                           dump<"\n">(b, ix);
-                        }
-                        else {
+                        if constexpr (N > 0) {
                            dump<",\n">(b, ix);
+                           dumpn<Opts.indentation_char>(ctx.indentation_level, b, ix);
                         }
-                        dumpn<Opts.indentation_char>(ctx.indentation_level, b, ix);
                      }
                      else {
                         dump<"\": \"">(b, ix);
                         dump_maybe_empty(ids_v<T>[value.index()], b, ix);
                         if constexpr (N == 0) {
-                           dump<"\"\n">(b, ix);
+                           dump<'"'>(b, ix);
                         }
                         else {
                            dump<"\",\n">(b, ix);
+                           dumpn<Opts.indentation_char>(ctx.indentation_level, b, ix);
                         }
-                        dumpn<Opts.indentation_char>(ctx.indentation_level, b, ix);
                      }
                   }
                   else {
@@ -1411,7 +1678,16 @@ namespace glz
                         }
                      }
                   }
-                  to<JSON, V>::template op<opening_and_closing_handled<Opts>()>(val, ctx, b, ix);
+                  if constexpr (is_memory_object<V>) {
+                     if (!val) [[unlikely]] {
+                        ctx.error = error_code::invalid_variant_object;
+                        return;
+                     }
+                     to<JSON, memory_type<V>>::template op<opening_and_closing_handled<Opts>()>(*val, ctx, b, ix);
+                  }
+                  else {
+                     to<JSON, V>::template op<opening_and_closing_handled<Opts>()>(val, ctx, b, ix);
+                  }
                   // If we skip everything then we may have an extra comma, which we want to revert
                   if constexpr (Opts.skip_null_members) {
                      if (b[ix - 1] == ',') {
@@ -1995,6 +2271,161 @@ namespace glz
       }
    };
 
+   // ============================================
+   // std::chrono serialization
+   // ============================================
+
+   // Duration: serialize as count
+   template <is_duration T>
+      requires(not custom_write<T>)
+   struct to<JSON, T>
+   {
+      template <auto Opts, class B>
+      GLZ_ALWAYS_INLINE static void op(auto&& value, is_context auto&& ctx, B&& b, auto&& ix) noexcept
+      {
+         using Rep = typename std::remove_cvref_t<T>::rep;
+         to<JSON, Rep>::template op<Opts>(value.count(), ctx, b, ix);
+      }
+   };
+
+   // system_clock::time_point: serialize as ISO 8601 string
+   // Zero-allocation implementation writing directly to buffer
+   template <is_system_time_point T>
+      requires(not custom_write<T>)
+   struct to<JSON, T>
+   {
+      template <auto Opts, class B>
+      static void op(auto&& value, [[maybe_unused]] is_context auto&& ctx, B&& b, auto&& ix) noexcept
+      {
+         using namespace std::chrono;
+         using TP = std::remove_cvref_t<T>;
+         using Duration = typename TP::duration;
+
+         // Split into date and time-of-day
+         const auto dp = floor<days>(value);
+         const year_month_day ymd{dp};
+         const hh_mm_ss tod{floor<Duration>(value - dp)};
+
+         // Extract components
+         const int yr = static_cast<int>(ymd.year());
+         const unsigned mo = static_cast<unsigned>(ymd.month());
+         const unsigned dy = static_cast<unsigned>(ymd.day());
+         const auto hr = static_cast<unsigned>(tod.hours().count());
+         const auto mi = static_cast<unsigned>(tod.minutes().count());
+         const auto sc = static_cast<unsigned>(tod.seconds().count());
+
+         // Calculate fractional digits based on duration precision
+         constexpr size_t frac_digits = []() constexpr {
+            using Period = typename Duration::period;
+            if constexpr (std::ratio_greater_equal_v<Period, std::ratio<1>>) {
+               return 0; // seconds or coarser
+            }
+            else if constexpr (std::ratio_greater_equal_v<Period, std::milli>) {
+               return 3; // milliseconds
+            }
+            else if constexpr (std::ratio_greater_equal_v<Period, std::micro>) {
+               return 6; // microseconds
+            }
+            else {
+               return 9; // nanoseconds or finer
+            }
+         }();
+
+         // Max size: "YYYY-MM-DDTHH:MM:SS.nnnnnnnnnZ" = 30 + quotes = 32
+         constexpr size_t max_size = 22 + (frac_digits > 0 ? 1 + frac_digits : 0);
+         maybe_pad<max_size>(b, ix);
+
+         // Helper to write N-digit zero-padded number
+         auto write_digits = [&]<size_t N>(uint64_t val) {
+            for (size_t i = N; i > 0; --i) {
+               b[ix + i - 1] = static_cast<char>('0' + val % 10);
+               val /= 10;
+            }
+            ix += N;
+         };
+
+         if constexpr (not Opts.raw) {
+            b[ix++] = '"';
+         }
+         write_digits.template operator()<4>(static_cast<uint64_t>(yr));
+         b[ix++] = '-';
+         write_digits.template operator()<2>(mo);
+         b[ix++] = '-';
+         write_digits.template operator()<2>(dy);
+         b[ix++] = 'T';
+         write_digits.template operator()<2>(hr);
+         b[ix++] = ':';
+         write_digits.template operator()<2>(mi);
+         b[ix++] = ':';
+         write_digits.template operator()<2>(sc);
+
+         // Write fractional seconds if duration is finer than seconds
+         if constexpr (frac_digits > 0) {
+            b[ix++] = '.';
+            const auto subsec = tod.subseconds();
+            if constexpr (frac_digits == 3) {
+               write_digits.template operator()<3>(static_cast<uint64_t>(duration_cast<milliseconds>(subsec).count()));
+            }
+            else if constexpr (frac_digits == 6) {
+               write_digits.template operator()<6>(static_cast<uint64_t>(duration_cast<microseconds>(subsec).count()));
+            }
+            else {
+               write_digits.template operator()<9>(static_cast<uint64_t>(duration_cast<nanoseconds>(subsec).count()));
+            }
+         }
+
+         b[ix++] = 'Z';
+         if constexpr (not Opts.raw) {
+            b[ix++] = '"';
+         }
+      }
+   };
+
+   // steady_clock::time_point: serialize as count in the time_point's native duration
+   template <is_steady_time_point T>
+      requires(not custom_write<T>)
+   struct to<JSON, T>
+   {
+      template <auto Opts, class B>
+      GLZ_ALWAYS_INLINE static void op(auto&& value, is_context auto&& ctx, B&& b, auto&& ix) noexcept
+      {
+         using Duration = typename std::remove_cvref_t<T>::duration;
+         using Rep = typename Duration::rep;
+         const auto count = value.time_since_epoch().count();
+         to<JSON, Rep>::template op<Opts>(count, ctx, b, ix);
+      }
+   };
+
+   // high_resolution_clock::time_point when it's a distinct type (rare)
+   template <is_high_res_time_point T>
+      requires(not custom_write<T>)
+   struct to<JSON, T>
+   {
+      template <auto Opts, class B>
+      GLZ_ALWAYS_INLINE static void op(auto&& value, is_context auto&& ctx, B&& b, auto&& ix) noexcept
+      {
+         // Treat like steady_clock - serialize as count since epoch is implementation-defined
+         using Duration = typename std::remove_cvref_t<T>::duration;
+         using Rep = typename Duration::rep;
+         const auto count = value.time_since_epoch().count();
+         to<JSON, Rep>::template op<Opts>(count, ctx, b, ix);
+      }
+   };
+
+   // epoch_time wrapper: serialize as numeric Unix timestamp
+   template <class Duration>
+      requires(not custom_write<epoch_time<Duration>>)
+   struct to<JSON, epoch_time<Duration>>
+   {
+      template <auto Opts, class B>
+      GLZ_ALWAYS_INLINE static void op(auto&& wrapper, is_context auto&& ctx, B&& b, auto&& ix) noexcept
+      {
+         using Rep = typename Duration::rep;
+         const auto count = std::chrono::duration_cast<Duration>(wrapper.value.time_since_epoch()).count();
+         to<JSON, Rep>::template op<Opts>(count, ctx, b, ix);
+      }
+   };
+
    template <write_supported<JSON> T, output_buffer Buffer>
    [[nodiscard]] error_ctx write_json(T&& value, Buffer&& buffer)
    {
@@ -2025,6 +2456,107 @@ namespace glz
       return write<Partial, opts{}>(std::forward<T>(value), std::forward<Buffer>(buffer));
    }
 
+   // Runtime partial write - writes only the keys specified at runtime
+   // Keys is a range of string-like types (e.g., std::vector<std::string>, std::array<std::string_view, N>)
+   // Output key order matches the order in the input container
+   // Returns error_code::unknown_key if any key doesn't exist in the struct
+
+   template <auto Opts = opts{}, class T, class Keys, output_buffer Buffer>
+      requires((glaze_object_t<T> || reflectable<T>) && range<Keys>)
+   [[nodiscard]] error_ctx write_json_partial(T&& value, const Keys& keys, Buffer&& buffer)
+   {
+      if constexpr (resizable<Buffer>) {
+         if (buffer.size() < 2 * write_padding_bytes) {
+            buffer.resize(2 * write_padding_bytes);
+         }
+      }
+      context ctx{};
+      size_t ix = 0;
+      to_runtime_partial<std::remove_cvref_t<T>>::template op<set_json<Opts>()>(keys, std::forward<T>(value), ctx,
+                                                                                buffer, ix);
+      if constexpr (resizable<Buffer>) {
+         buffer.resize(ix);
+      }
+      return {ctx.error, ctx.custom_error_message};
+   }
+
+   template <auto Opts = opts{}, class T, class Keys, raw_buffer Buffer>
+      requires((glaze_object_t<T> || reflectable<T>) && range<Keys>)
+   [[nodiscard]] glz::expected<size_t, error_ctx> write_json_partial(T&& value, const Keys& keys, Buffer&& buffer)
+   {
+      context ctx{};
+      size_t ix = 0;
+      to_runtime_partial<std::remove_cvref_t<T>>::template op<set_json<Opts>()>(keys, std::forward<T>(value), ctx,
+                                                                                buffer, ix);
+      if (bool(ctx.error)) [[unlikely]] {
+         return glz::unexpected(error_ctx{ctx.error, ctx.custom_error_message});
+      }
+      return {ix};
+   }
+
+   template <auto Opts = opts{}, class T, class Keys>
+      requires((glaze_object_t<T> || reflectable<T>) && range<Keys>)
+   [[nodiscard]] glz::expected<std::string, error_ctx> write_json_partial(T&& value, const Keys& keys)
+   {
+      std::string buffer{};
+      const auto ec = write_json_partial<Opts>(std::forward<T>(value), keys, buffer);
+      if (bool(ec)) [[unlikely]] {
+         return glz::unexpected(ec);
+      }
+      return {std::move(buffer)};
+   }
+
+   // Runtime exclude write - writes all keys EXCEPT those specified at runtime
+   // Keys is a range of string-like types (e.g., std::vector<std::string>, std::array<std::string_view, N>)
+   // Output key order matches the struct definition order
+   // Returns error_code::unknown_key if any exclude key doesn't exist in the struct
+
+   template <auto Opts = opts{}, class T, class Keys, output_buffer Buffer>
+      requires((glaze_object_t<T> || reflectable<T>) && range<Keys>)
+   [[nodiscard]] error_ctx write_json_exclude(T&& value, const Keys& exclude_keys, Buffer&& buffer)
+   {
+      if constexpr (resizable<Buffer>) {
+         if (buffer.size() < 2 * write_padding_bytes) {
+            buffer.resize(2 * write_padding_bytes);
+         }
+      }
+      context ctx{};
+      size_t ix = 0;
+      to_runtime_exclude<std::remove_cvref_t<T>>::template op<set_json<Opts>()>(exclude_keys, std::forward<T>(value),
+                                                                                ctx, buffer, ix);
+      if constexpr (resizable<Buffer>) {
+         buffer.resize(ix);
+      }
+      return {ctx.error, ctx.custom_error_message};
+   }
+
+   template <auto Opts = opts{}, class T, class Keys, raw_buffer Buffer>
+      requires((glaze_object_t<T> || reflectable<T>) && range<Keys>)
+   [[nodiscard]] glz::expected<size_t, error_ctx> write_json_exclude(T&& value, const Keys& exclude_keys,
+                                                                     Buffer&& buffer)
+   {
+      context ctx{};
+      size_t ix = 0;
+      to_runtime_exclude<std::remove_cvref_t<T>>::template op<set_json<Opts>()>(exclude_keys, std::forward<T>(value),
+                                                                                ctx, buffer, ix);
+      if (bool(ctx.error)) [[unlikely]] {
+         return glz::unexpected(error_ctx{ctx.error, ctx.custom_error_message});
+      }
+      return {ix};
+   }
+
+   template <auto Opts = opts{}, class T, class Keys>
+      requires((glaze_object_t<T> || reflectable<T>) && range<Keys>)
+   [[nodiscard]] glz::expected<std::string, error_ctx> write_json_exclude(T&& value, const Keys& exclude_keys)
+   {
+      std::string buffer{};
+      const auto ec = write_json_exclude<Opts>(std::forward<T>(value), exclude_keys, buffer);
+      if (bool(ec)) [[unlikely]] {
+         return glz::unexpected(ec);
+      }
+      return {std::move(buffer)};
+   }
+
    template <write_supported<JSON> T, class Buffer>
    [[nodiscard]] error_ctx write_jsonc(T&& value, Buffer&& buffer)
    {
@@ -2048,6 +2580,6 @@ namespace glz
    }
 }
 
-#if defined(_MSC_VER)
+#if defined(_MSC_VER) && !defined(__clang__)
 #pragma warning(pop)
 #endif
